Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: chrome/browser/shell_integration.h

Issue 1588733005: Reduce MigrateChromiumShortcuts to only handling taskbar pins. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@a2_gab_more_metro_cleanup
Patch Set: review:grt Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/shell_integration_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/shell_integration.h
diff --git a/chrome/browser/shell_integration.h b/chrome/browser/shell_integration.h
index 7073b88f8097b49e3022bcc0c0f78e2f0fe7f990..f2c629a57ae819495dcdee1ce6e4c02b86bcb567 100644
--- a/chrome/browser/shell_integration.h
+++ b/chrome/browser/shell_integration.h
@@ -155,20 +155,19 @@ class ShellIntegration {
static base::string16 GetAppListAppModelIdForProfile(
const base::FilePath& profile_path);
// Migrates existing chrome shortcuts by tagging them with correct app id.
// see http://crbug.com/28104
- static void MigrateChromiumShortcuts();
+ static void MigrateTaskbarPins();
// Migrates all shortcuts in |path| which point to |chrome_exe| such that they
- // have the appropriate AppUserModelId. Also clears the dual_mode property
- // from shortcuts that previously had it if requested by |clear_dual_mode|.
+ // have the appropriate AppUserModelId. Also clears the legacy dual_mode
+ // property from shortcuts with the default chrome app id.
// Returns the number of shortcuts migrated.
// This method should not be called prior to Windows 7.
// This method is only public for the sake of tests and shouldn't be called
// externally otherwise.
static int MigrateShortcutsInPathInternal(const base::FilePath& chrome_exe,
- const base::FilePath& path,
- bool clear_dual_mode);
+ const base::FilePath& path);
// Returns the path to the Start Menu shortcut for the given Chrome.
static base::FilePath GetStartMenuShortcut(const base::FilePath& chrome_exe);
« no previous file with comments | « no previous file | chrome/browser/shell_integration_win.cc » ('j') | no next file with comments »
@@ -155,20 +155,19 @@ class ShellIntegration {
static base::string16 GetAppListAppModelIdForProfile(
const base::FilePath& profile_path);
- // Migrates existing chrome shortcuts by tagging them with correct app id.
+ // Migrates existing chrome taskbar pins by tagging them with correct app id.
// see http://crbug.com/28104

Powered by Google App Engine
This is Rietveld 408576698